
Basic
=====


.. automodule:: opendssdirect.Basic
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.Basic.AllowForms

    Bool flag on the status of allowing formsBool flag to disable forms (once disabled, can't be enabled again)

.. function:: opendssdirect.Basic.Classes

    List of the names of intrinsic classes

.. function:: opendssdirect.Basic.ClearAll

    Clears all circuit definitions

.. function:: opendssdirect.Basic.DataPath

    Default file path for reports, etc.Set the default file path for reports, etc.

.. function:: opendssdirect.Basic.DefaultEditor

    The path name for the default text editor

.. function:: opendssdirect.Basic.NewCircuit

    Make a new circuit

.. function:: opendssdirect.Basic.NumCircuits

    Number of Circuits currently defined

.. function:: opendssdirect.Basic.NumClasses

    Number of DSS intrinsic classes

.. function:: opendssdirect.Basic.NumUserClasses

    Number of user-defined classes

.. function:: opendssdirect.Basic.Reset

    Resets DSS Initialization for restarts

.. function:: opendssdirect.Basic.ShowPanel

    Shows non-MDI child form of the Main DSS Edit Form

.. function:: opendssdirect.Basic.Start

    Validate the user and start OpenDSS; returns true if successful

.. function:: opendssdirect.Basic.UserClasses

    List of the names of user-defined classes

.. function:: opendssdirect.Basic.Version

    Get version string for OpenDSS

